{ config, lib, pkgs, ... }:

{
  services = {
    transmission = {
      enable = true;
      home = "/var/lib/transmission";
      port = 9091;
      settings = {
        rpc-bind-address = "127.0.0.1";
        rpc-host-whitelist = "*";
        rpc-whitelist-enabled = false;
        peer-port = 51413;
        incomplete-dir = "/mnt/medias/incomplete";
      };
    };

    radarr.enable = true;
    sonarr.enable = true;
    jackett.enable = true;

    jellyfin = {
      enable = true;
      package = pkgs.jellyfin;
    };

    navidrome = {
      enable = true;
      settings = {
        MusicFolder = "/mnt/medias/musique";
        ImageCacheSize = 0;
      };
    };
  };

  systemd.services.transmission.serviceConfig.BindPaths = [ "/mnt/medias" ];

  networking = {
    firewall.allowedTCPPorts = [
      config.services.transmission.settings.peer-port
    ];

    firewall.allowedUDPPorts = [
      config.services.transmission.settings.peer-port
    ];
  };

  virtualisation.oci-containers = {
    backend = "podman";
    containers = {
      slimserver = {
        image = "docker.io/lmscommunity/logitechmediaserver:stable";
        volumes = [
          "/mnt/medias/musique:/music:ro"
          "/var/lib/slimserver:/config:rw"
          "/etc/localtime:/etc/localtime:ro"
        ];
        ports = [
          "9000:9000/tcp"
          "9090:9090/tcp"
          "3483:3483/tcp"
          "3483:3483/udp"
        ];
        extraOptions = ["--pull=always"];
      };
    };
  };
}
